.. PyGridFit documentation master file, created by
   sphinx-quickstart on Fri Sep  2 10:14:23 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyGridFit's documentation!
=====================================

PyGridFit is a Python implementation of the MATLAB Surface Fitting library
GridFit_.

.. image:: _static/example.png
  :alt: Example surface fitted by GridFit.

To install from PyPI::

  pip install gridfit

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage.ipynb
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _GridFit: https://www.mathworks.com/matlabcentral/fileexchange/8998-surface-fitting-using-gridfit
